---
title: parameter
sidebarTitle: parameter
---

# `catalax.model.parameter`

## Classes

### `Identifiability` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/parameter.py#L9" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

### `HDI` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/parameter.py#L15" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

### `Parameter` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/parameter.py#L23" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>
